 /*====================================================================
Project:    Find the Fake: Boosting Resistance to Misinformation 
			in Jordan with a WhatsApp Chatbot Game
Author:        
----------------------------------------------------------------------
Creation Date:    13 Nov 2022 - 09:58:31
====================================================================*/

clear all
macro drop _all
set matsize 11000
set more off

* Reproducibility team: Please change directory as needed
global dir "."
sysdir set PLUS "${dir}/ado"

* Graph Scheme
set scheme s1color

* Install commands
/*
ssc install outreg2, replace
ssc install missings, replace 
ssc install wyoung, replace 
ssc install coefplot, replace 
ssc install violinplot, replace 
ssc install dstat, replace 
ssc install moremata, replace 
net install grc1leg, from(http://www.stata.com/users/vwiggins/)
ssc install ipfraking, replace
*/
/*====================================================================
======================================================================
							Cleaning Data					
======================================================================
====================================================================*/

use "${dir}/reproducibility_data.dta", clear

/*====================================================================
						Drop Duplicates
====================================================================*/

duplicates tag id, gen(dup_id)

* Keep first observation for each user
sort id Exited_end Started_intro
by id: drop if _n>1


/*====================================================================
                   Drop and rename variables
====================================================================*/


drop t_*Cate* intro_*C* end_*C* 
foreach var of varlist t_*Value* intro_*V* end_*V*  {
	
	local name= subinstr("`var'","Value","Category",.)  
	rename `var' `name'
	
}


foreach var of varlist *In* {
	rename `var' i_`var'
}

foreach var of varlist *Pl* {
	rename `var' p_`var'
}

rename roundsfinalscoreVal* game_score
drop *Value* *Text*  
drop seedC* roundsfinalscoreC* summaryscoreshortgame*

foreach var of varlist *Ro* {
	rename `var' g_`var'
}

foreach var of varlist *Ga* {
	rename `var' gs_`var'
}


foreach var of varlist *Category* {
	local name= substr("`var'", 1, strpos("`var'", "Cat") - 1)  
	rename `var' `name'
}

foreach var of varlist _all {
	capture confirm string variable `var'
		if !_rc {
			replace `var'="" if `var'=="Other"
			count if `var'=="All Responses"
			if `r(N)'>0 drop `var'
		}
}

missings dropvars, force
missings dropobs, force

/*====================================================================
							Fix Format
====================================================================*/

foreach var of varlist ?_t_* *intro_* *end_* seed {
	di "`var'"
	replace `var'= substr(`var', 1, strpos(`var', ".") - 1)
	replace `var'=subinstr(`var', "T",  " ", . )
	gen `var'_t=clock(`var', "YMDhms")
	format `var'_t %tc
	drop `var'
	rename `var'_t `var'
}

label define l_correct 0 "Incorrect" 1 "Correct", replace
global correct g_rd1_q1 g_rd1_q2 g_rd2_q1 g_rd2_q2 g_rd2_q3 g_rd3_q1 gs_rd1_q2 gs_rd2_q3 gs_rd3_q1

foreach label in correct {
	foreach var in ${`label'} {
	di "`label' - `var'"
	encode `var', gen(l_`var') label(l_`label')
	drop `var'
	rename l_`var' `var'

	}

}

foreach var of varlist _all {
	capture destring `var', replace
}

label define l_vaccination 1 "Yes" 2 "No, but plan to" 3 "No, and don't want to" 4 "N/A"
label values vaccination l_vaccination

label define l_confidence 1 "More" 2 "Same" 3 "Less" 
label values confidence l_confidence

label define l_challenging 1 "Easy" 2 "Right" 3 "Difficult" 
label values challenging l_challenging

rename nps recommend
label define l_recommend 1 "Yes" 2 "Maybe" 3 "No" 
label values recommend l_recommend

label define l_survey_gender 1 "Male" 2 "Female" 3 "Other" 4 "N/A" 
label values survey_gender l_survey_gender

label define l_age 1 "18-29" 2 "30-39" 3 "40-49" 4 "50-59" 5 "60+" 6 "N/A" 
label values age l_age

label define l_education 1 "No" 2 "Primary" 3 "Secondary" 4 "Tertiary" 5 "N/A"
label values education l_education

/*====================================================================
					Scoring Evaluation
====================================================================*/

gen share_q2=share_q2_exp if share_q2_exp!=.
replace share_q2=share_q2_emo if share_q2_emo!=.


* Reverse-code items 
foreach var of varlist eval_q? share_q? {
	
	recode `var' (1=4) (2=3) (3=2) (4=1), gen(r_`var')
	
}

foreach var of varlist confidence recommend {
	
	recode `var' (1=3) (2=2) (3=1), gen(r_`var')
	
}

gen ad_ds6= (r_eval_q1 + r_eval_q2 + r_eval_q5)/3 - (r_eval_q3 + r_eval_q4 + r_eval_q6)/3 if r_eval_q6!=.
label var ad_ds6 "Misinformation Discernment"

gen ad_ds5= (r_eval_q1 + r_eval_q2)/2 - (r_eval_q3 + r_eval_q4 + r_eval_q6)/3 if r_eval_q6!=.
label var ad_ds5 "Misinformation Discernment (Without Digital)"

gen miss= (r_eval_q1 + r_eval_q2 + r_eval_q5)/3 if r_eval_q6!=.
label var miss "Misinformation Judgements of Misleading Headline"

gen non_miss= (r_eval_q3 + r_eval_q4 + r_eval_q6)/3 if r_eval_q6!=.
label var non_miss "Misinformation Judgements of Non-Misleading Headline"

gen ad_share=(share_q1 - share_q2)
label var ad_share "Sharing Discernment"

gen treatment_status=.
replace treatment_status=0 if Started_evaluation!=. & Started_game_r1==. & Started_infographics==. & Started_example==. & Started_game_short==.  & Started_placebo==.
replace treatment_status=1 if  Started_placebo!=. 
replace treatment_status=2 if  Started_game_r1!=.
replace treatment_status=3 if  Started_game_short!=.
replace treatment_status=4 if  Started_infographics!=. 

label define l_treatment_status 0 "Control" 1 "Placebo" 2 "Comprehensive Active Inoculation" 3 "Brief Active Inoculation" 4 "Passive Inoculation"  
label values treatment_status l_treatment_status

gen t1=0 if treatment_status==1
replace t1=1 if treatment_status==0
label define l_t1 0 "Placebo" 1 "Control" 
label values t1 l_t1

gen t2=0 if treatment_status==1
replace t2=1 if treatment_status==2
label define l_t2 0 "Placebo" 1 "Comprehensive Active Inoculation" 
label values t2 l_t2

gen t3=0 if treatment_status==1
replace t3=1 if treatment_status==3
label define l_t3 0 "Placebo" 1 "Brief Active Inoculation" 
label values t3 l_t3

gen t4=0 if treatment_status==1
replace t4=1 if treatment_status==4
label define l_t4 0 "Placebo" 1 "Passive Inoculation" 
label values t4 l_t4

gen t0=1 if treatment_status==1 
label define l_t0 1 "Placebo" 
label values t0 l_t0

* Standardize outcomes

foreach var of varlist ad_ds6 miss non_miss ad_share share_q2 share_q1 r_confidence challenging r_recommend ad_ds5 {
	egen std_`var'=std(`var') if education!=.
	label var std_`var' "`: variable label `var''"
}

* Attention Checks

gen i_check_score=0 if Started_infographics!=.
replace i_check_score=1 if i_check_info_1==3
replace i_check_score=i_check_score + 1 if i_check_info_2==2
replace i_check_score=i_check_score + 1 if i_check_info_3==2

gen i_d_check=.
replace i_d_check=0 if i_check_score==0 | i_check_score==1 | i_check_score==2
replace i_d_check=1 if  i_check_score==3
label define l_i_d_check 0 "Failed Attention Checks" 1 "Succeeded ALL Attention Checks" , replace
label values i_d_check l_i_d_check

gen p_check_score=0 if Started_placebo!=.
replace p_check_score=1 if p_check_info_1==3
replace p_check_score=p_check_score + 1 if p_check_info_2==2
replace p_check_score=p_check_score + 1 if p_check_info_3==2

gen p_d_check=.
replace p_d_check=0 if p_check_score==0 | p_check_score==1 | p_check_score==2
replace p_d_check=1 if  p_check_score==3
label define l_p_d_check 0 "Failed Attention Checks" 1 "Succeeded ALL Attention Checks" , replace
label values p_d_check l_p_d_check

/*====================================================================
							Labels
====================================================================*/

label var vaccination "Vaccinated for COVID-19"
label var r_confidence "Confidence on identifying misinformation after the game"
label var challenging "Game difficulty"
label var r_recommend "Recommend the game"
label var survey_gender "Gender"
label var age "Age"
label var education "Education"
label var game_score "Game - Score"
label var shortgame_score "Brief Game - Score"

label var eval_q1 "Evaluation - Q1"
label var eval_q2 "Evaluation - Q2"
label var eval_q3 "Evaluation - Q3"
label var eval_q4 "Evaluation - Q4"
label var eval_q5 "Evaluation - Q5"
label var eval_q6 "Evaluation - Q6"
label var share_q1 "Evaluation - Q7 (Share 1)"
label var share_q2 "Evaluation - Q8 (Share 2)"
label var share_q2_exp "Evaluation - Q8 (Share Expert)"
label var share_q2_emo "Evaluation - Q8 (Share Emotion)"

save "${dir}/reproducibility_data_processed.dta", replace  

/*====================================================================
======================================================================
							Paper Results 
======================================================================
====================================================================*/

use "${dir}/reproducibility_data_processed.dta", clear

drop if Started_example!=. // Example treatment arm dropped
drop if education!=. & vaccination==. // Remove issues with logic jumps

/*====================================================================
							Figure 2 
====================================================================*/

* Facebook Ads recruitment
count
* Intro and opt-in
count if treatment_status!=.
* Treatment arms
tab treatment_status
* Comprehensive Active Inoculation / * Intervention complete
	count if g_rd3_q1!=.
* Brief Active Inoculation / * Intervention complete
	count if gs_rd3_q1!=.
* Passive Inoculation / * Intervention complete
	count if i_check_info_3!=.	
* Placebo / * Intervention complete
	count if p_check_info_3!=.	
* Intervention
	forval i=0/4 {

	* Evaluation
	di "Evaluation - `: label l_treatment_status `i''"
	count if share_q2!=. & treatment_status==`i'
	* Survey
	di "Survey - `: label l_treatment_status `i''"
	count if education!=. & treatment_status==`i'
	} 
	
/*====================================================================
							Table 2					
====================================================================*/

gen do_treat=0
replace do_treat=1 if treatment_status!=. & Started_evaluation!=.
label var do_treat "Completed treatment"

gen do_s_eval=0
replace do_s_eval=1 if treatment_status!=. & eval_q1!=.
label var do_s_eval "Started evaluation"

gen do_eval=0
replace do_eval=1 if treatment_status!=. & share_q2!=.
label var do_eval "Completed evaluation"

gen do_s_survey=0
replace do_s_survey=1 if treatment_status!=. & confidence!=.
label var do_s_survey "Started survey"

gen do_all=0
replace do_all=1 if treatment_status!=. & age!=. & education!=. & survey_gender!=. & vaccination!=.
label var do_all "Completed survey (end)"

foreach var of varlist do_*  {
	reg `var' ib1.treatment_status, r
	outreg2 using "${dir}/Results/Table 2.xls", append label dec(3)
}

/*=================================================================================
									Table 3	
==================================================================================*/

gen gr_treatment=""

foreach var of varlist ad_ds6 miss non_miss {

gen mean_`var'=.
gen sd_`var'=. 

loca l=1
forval i=0/4 {
	
	replace gr_treatment="`: label l_treatment_status `i''" in `l'
	sum `var' if t`i'==1 & education!=.
	replace mean_`var'=`r(mean)' in `l'
	replace sd_`var'=`r(sd)' in `l'
	local l = `l' + 1
}
}

export excel gr_* mean_* sd_* using "${dir}/Results/Table 3.xlsx", sheetreplace firstrow(varlabels) 


/*====================================================================
								Table 4	
====================================================================*/

 // PANEL A
foreach var of varlist std_ad_ds6  std_miss std_non_miss  {
	reg `var' ib1.treatment_status i.age i.education i.survey_gender i.vaccination if education!=., r
	outreg2 using "${dir}/Results/Table 4A.xls", append label dec(3)
}


* Westfall-Young stepdown adjusted p-values
foreach i of numlist 0 2 3 4 {
wyoung std_ad_ds6  std_miss std_non_miss std_ad_share std_share_q2 std_share_q1   std_r_confidence std_challenging std_r_recommend, cmd(reg OUTCOMEVAR ib1.treatment_status i.age i.education i.survey_gender i.vaccination if education!=., r) familyp(`i'.treatment_status) bootstraps(1000) seed(1984) 
}

// PANEL B
foreach var of varlist std_ad_ds6  std_miss std_non_miss  {
	reg `var' ib4.treatment_status i.age i.education i.survey_gender i.vaccination if education!=., r
	outreg2 using "${dir}/Results/Table 4B.xls", append label dec(3)
}


* Westfall-Young stepdown adjusted p-values
forval i=0/3 {
wyoung std_ad_ds6  std_miss std_non_miss std_ad_share std_share_q2 std_share_q1   std_r_confidence std_challenging std_r_recommend, cmd(reg OUTCOMEVAR ib4.treatment_status i.age i.education i.survey_gender i.vaccination if education!=., r) familyp(`i'.treatment_status) bootstraps(1000) seed(1984) 
}

/*====================================================================
							Figure 3	
====================================================================*/

reg ad_ds6 ib1.treatment_status i.age i.education i.survey_gender i.vaccination if education!=., r
margins i.treatment_status
matrix all=r(table)[1,1...]' , r(table)[2,1...]'
matrix list all

coefplot (matrix(all[,1]), se(2)) , vertical xlabel(1 "Control" 2 "Placebo" 3 `" "Comprehensive" "Active" "Inoculation" "'  4 `" "Brief" "Active" "Inoculation" "' 5 `" "Passive" "Inoculation" "' , labsize(small))   ylabel(0(1)2) recast(bar) ciopts(recast(rcap)) citop barwidth(0.25) fcolor(*.5) ytitle("Misinformation Discernment", size(small)) 
graph export "${dir}/Results/Figure 3A.png", replace


reg miss ib1.treatment_status i.age i.education i.survey_gender i.vaccination if education!=., r
margins i.treatment_status
matrix miss=r(table)[1,1...]' , r(table)[2,1...]'

reg non_miss ib1.treatment_status i.age i.education i.survey_gender i.vaccination if education!=., r
margins i.treatment_status
matrix non_miss=r(table)[1,1...]' , r(table)[2,1...]'

coefplot (matrix(miss[,1]), se(2)) (matrix(non_miss[,1]), se(2)), vertical xlabel(1 "Control" 2 "Placebo" 3 `" "Comprehensive" "Active" "Inoculation" "'  4 `" "Brief" "Active" "Inoculation" "' 5 `" "Passive" "Inoculation" "', labsize(small)) recast(bar)  ciopts(recast(rcap)) citop barwidth(0.25) fcolor(*.5)  legend( label (1 "Misleading Headline") label (3 "Non-Misleading Headline") size(small)) ylabel(1(1)3) ytitle("Misinformation Judgements", size(small))  
graph export "${dir}/Results/Figure 3B.png", replace


/*=================================================================================
								Table 5 
==================================================================================*/

foreach var of varlist ad_share share_q1 share_q2 {

gen mean_`var'=.
gen sd_`var'=. 

loca l=1
forval i=0/4 {
	
	replace gr_treatment="`: label l_treatment_status `i''" in `l'
	sum `var' if t`i'==1 & education!=.
	replace mean_`var'=`r(mean)' in `l'
	replace sd_`var'=`r(sd)' in `l'
	local l = `l' + 1
}
}

export excel gr_* mean_ad_s* sd_ad_s* mean_sh* sd_sh*  using "${dir}/Results/Table 5.xlsx", sheetreplace firstrow(varlabels) 

/*====================================================================
							Table 6 
====================================================================*/

foreach var of varlist std_ad_share std_share_q2 std_share_q1  {
	reg `var' ib1.treatment_status i.age i.education i.survey_gender i.vaccination if education!=., r
	outreg2 using "${dir}/Results/Table 6A.xls", append label dec(3)
}

* Westfall-Young stepdown adjusted p-values
/*
foreach i of numlist 0 2 3 4 {
wyoung std_ad_ds6  std_miss std_non_miss std_ad_share std_share_q2 std_share_q1   std_r_confidence std_challenging std_r_recommend, cmd(reg OUTCOMEVAR ib1.treatment_status i.age i.education i.survey_gender i.vaccination if education!=., r) familyp(`i'.treatment_status) bootstraps(1000) seed(1984) 
}
*/
 
foreach var of varlist std_ad_share std_share_q2 std_share_q1  {
	reg `var' ib4.treatment_status i.age i.education i.survey_gender i.vaccination if education!=., r
	outreg2 using "${dir}/Results/Table 6B.xls", append label dec(3)
}

* Westfall-Young stepdown adjusted p-values
/*
forval i=0/3 {
wyoung std_ad_ds6  std_miss std_non_miss std_ad_share std_share_q2 std_share_q1   std_r_confidence std_challenging std_r_recommend, cmd(reg OUTCOMEVAR ib4.treatment_status i.age i.education i.survey_gender i.vaccination if education!=., r) familyp(`i'.treatment_status) bootstraps(1000) seed(1984) 
}
*/
/*====================================================================
							Figure 4
====================================================================*/

reg ad_share ib1.treatment_status i.age i.education i.survey_gender i.vaccination if education!=., r
margins i.treatment_status
matrix all=r(table)[1,1...]' , r(table)[2,1...]'
matrix list all

coefplot (matrix(all[,1]), se(2)) ,  xlabel(1 "Control" 2 "Placebo" 3 `" "Comprehensive" "Active" "Inoculation" "'  4 `" "Brief" "Active" "Inoculation" "' 5 `" "Passive" "Inoculation" "' , labsize(small)) vertical  ylabel(0(1)2) recast(bar) ciopts(recast(rcap)) citop barwidth(0.25) fcolor(*.5) ytitle("Sharing Discernment", size(small)) 
graph export "${dir}/Results/Figure 4A.png", replace


reg share_q2 ib1.treatment_status i.age i.education i.survey_gender i.vaccination if education!=., r
margins i.treatment_status
matrix miss=r(table)[1,1...]' , r(table)[2,1...]'

reg share_q1 ib1.treatment_status i.age i.education i.survey_gender i.vaccination if education!=., r
margins i.treatment_status
matrix non_miss=r(table)[1,1...]' , r(table)[2,1...]'

coefplot (matrix(miss[,1]), se(2)) (matrix(non_miss[,1]), se(2)), vertical xlabel(1 "Control" 2 "Placebo" 3 `" "Comprehensive" "Active" "Inoculation" "'  4 `" "Brief" "Active" "Inoculation" "' 5 `" "Passive" "Inoculation" "', labsize(small)) recast(bar)  ciopts(recast(rcap)) citop barwidth(0.25) fcolor(*.5)  legend( label (1 "Misleading Headline") label (3 "Non-Misleading Headline") size(small)) ylabel(1(1)3) ytitle("Sharing Intention", size(small))  
graph export "${dir}/Results/Figure 4B.png", replace

/*====================================================================
								Table 7 
====================================================================*/


foreach var of varlist std_r_confidence std_challenging std_r_recommend  {
	reg `var' ib1.treatment_status i.age i.education i.survey_gender i.vaccination if education!=., r
	outreg2 using "${dir}/Results/Table 7A.xls", append label dec(3)
}

* Westfall-Young stepdown adjusted p-values
/*
foreach i of numlist 0 2 3 4 {
wyoung std_ad_ds6  std_miss std_non_miss std_ad_share std_share_q2 std_share_q1   std_r_confidence std_challenging std_r_recommend, cmd(reg OUTCOMEVAR ib1.treatment_status i.age i.education i.survey_gender i.vaccination if education!=., r) familyp(`i'.treatment_status) bootstraps(1000) seed(1984) 
}
*/
foreach var of varlist std_r_confidence std_challenging std_r_recommend  {
	reg `var' ib4.treatment_status i.age i.education i.survey_gender i.vaccination if education!=., r
	outreg2 using "${dir}/Results/Table 7B.xls", append label dec(3)
}

* Westfall-Young stepdown adjusted p-values
/*
forval i=0/3 {
wyoung std_ad_ds6  std_miss std_non_miss std_ad_share std_share_q2 std_share_q1   std_r_confidence std_challenging std_r_recommend, cmd(reg OUTCOMEVAR ib4.treatment_status i.age i.education i.survey_gender i.vaccination if education!=., r) familyp(`i'.treatment_status) bootstraps(1000) seed(1984) 
}
*/

/*====================================================================
							Figure 5
====================================================================*/

reg r_confidence ib1.treatment_status i.age i.education i.survey_gender i.vaccination if education!=., r
margins i.treatment_status
matrix conf=r(table)[1,1...]' , r(table)[2,1...]'

reg challenging ib1.treatment_status i.age i.education i.survey_gender i.vaccination if education!=., r
margins i.treatment_status
matrix chall=r(table)[1,1...]' , r(table)[2,1...]'

reg r_recommend ib1.treatment_status i.age i.education i.survey_gender i.vaccination if education!=., r
margins i.treatment_status
matrix rec=r(table)[1,1...]' , r(table)[2,1...]'

coefplot (matrix(conf[,1]), se(2)) (matrix(chall[,1]), se(2)) (matrix(rec[,1]), se(2)), vertical xlabel(1 "Control" 2 "Placebo" 3 `" "Comprehensive" "Active" "Inoculation" "'  4 `" "Brief" "Active" "Inoculation" "' 5 `" "Passive" "Inoculation" "', labsize(small)) recast(bar)  ciopts(recast(rcap)) citop barwidth(0.25) fcolor(*.5)  legend( label (1  "Confidence on identifying" "misinformation after" "the game" ) label (3 "Game difficulty") label (5 "Recommend the game") size(vsmall)) ylabel(1(1)3) ytitle("Score", size(small))  
graph export "${dir}/Results/Figure 5.png", replace

/*====================================================================
======================================================================
							Appendix 
======================================================================
====================================================================*/

/*====================================================================
							Appendix E
====================================================================*/


global mult_op vaccination survey_gender age education 

global balance vaccination_? survey_gender_? age_? education_?

foreach var of varlist $mult_op {
	tab `var', gen(`var'_)
}


local sub="if education!=."
local cond="& education!=."

foreach group of varlist t1 t2 t3 t4 {

	local treat="`group'"
	
		gen v_`group'=""
		gen `group'_pv=.
	foreach txt in "all" "g1" "g2" "diff" "sdiff" {
		gen `txt'_`group'=.
	}	
	
		local i = 1
		
		foreach var of varlist $balance {
			
			if "`group'"=="t1" egen std_`var'=std(`var')
			
			sum `var' `sub'
			local m=r(mean)
			local sd=r(sd)
			local N=r(N)
			sum `var' if `treat'==1 `cond'
			local m1=r(mean)
			local sd1=r(sd)
			local N1=r(N)
			sum `var' if `treat'==0 `cond'
			local m0=r(mean)
			local sd0=r(sd)
			local N0=r(N)
			display "`var' "
			sum `var' if `treat'!=.
			local N=r(N)
			if `N'>0 {
			reg `var' `treat' `sub', r
			local b=_b[`treat']
			local se=_se[`treat']
			local t=_b[`treat']/_se[`treat']
			local df=e(df_r)
			local pval=2*ttail(`df',abs(`t'))
			
			reg std_`var' `treat' `sub', r
			local b2=_b[`treat']
			local se2=_se[`treat']
			local t2=_b[`treat']/_se[`treat']
			local df2=e(df_r)
			local pval2=2*ttail(`df2',abs(`t2'))
			
			} 
			
			local j=`i' + 1
			replace v_`group'=  "`: variable label `var''"  in `i'
			replace all_`group'= `m' in `i' 
			replace all_`group'= `sd' in `j'
			replace g1_`group'= `m0' in `i' 
			replace g1_`group'= `sd0' in `j'
			replace g2_`group'= `m1' in `i' 
			replace g2_`group'= `sd1' in `j'
			replace diff_`group'= `b' in `i' 
			replace diff_`group'= `se' in `j'
			replace sdiff_`group'= `b2' in `i' 
			replace sdiff_`group'= `se2' in `j'
			replace `group'_pv = `pval' in `i'
			
			local i= `i' + 2
			}
			
			foreach txt in "all" "g1" "g2" "diff" "sdiff" {
			gen t_`txt'_`group'=round(`txt'_`group',0.01)
			tostring t_`txt'_`group', replace force  u
			replace t_`txt'_`group' = "0"+ t_`txt'_`group' if `txt'_`group'<1 & `txt'_`group'>-1
			replace t_`txt'_`group' = ustrregexrf(t_`txt'_`group', "0-.", "-0.")
			forval t=2(2)200 {  
				replace t_`txt'_`group' ="(" + t_`txt'_`group'  + ")" if _n==`t' 
			}
			
			if "`txt'"=="diff" | "`txt'"=="sdiff" {
			replace t_`txt'_`group' = t_`txt'_`group' +"*" if `group'_pv<=0.1 & `group'_pv>0.05
			replace t_`txt'_`group' = t_`txt'_`group' +"**" if `group'_pv <=0.05 & `group'_pv >0.01
			replace t_`txt'_`group' = t_`txt'_`group' +"***" if `group'_pv <=0.01 
			replace t_`txt'_`group' = "" if  t_`txt'_`group'=="0." |  t_`txt'_`group'=="(0.)" |  t_`txt'_`group'=="00" |  t_`txt'_`group'=="(00)"
			}
}

label var v_`group' "Variables"
label var t_all_`group' "All" 
count if `treat'==0 `cond'
label var t_g1_`group' "`: label l_`group' 0' (n=`r(N)')"
count if `treat'==1 `cond'
label var t_g2_`group' "`: label l_`group' 1' (n=`r(N)')"
label var t_diff_`group' "Diff (2)-(1)"
label var t_sdiff_`group' "Std. diff"

preserve

keep v_`group' t_*_`group'
drop if t_all_`group'=="." | t_all_`group'=="(.)"

export excel using "${dir}/Results/Appendix E.xlsx", sheetreplace sheet("`group'") firstrow(varlabels) 

restore	

}

/*=================================================================================
							Appendix G
==================================================================================*/

gen time_s_treat= (Started_evaluation - Started_game_r1)/60000 if  Started_game_r1!=. // Comprehensive Active Inoculation
replace time_s_treat= (Started_evaluation - Started_infographics)/60000 if Started_infographics!=. // Passive Inoculation 
replace time_s_treat= (Started_evaluation - Started_game_short)/60000 if Started_game_short!=. // Brief Active Inoculation
replace time_s_treat= (Started_evaluation - Started_placebo)/60000 if Started_placebo!=. // Passive Inoculation
replace time_s_treat= (Started_evaluation - Started_evaluation)/60000 if Started_evaluation!=. & treatment_status==0 // Placebo
label var time_s_treat "Duration of Intervention (min)"

gen t_tr=""
label var t_tr "Intervention"

gen time_s_eval =  (Started_survey - Started_evaluation)/60000
label var time_s_eval "Duration of Evaluation (min)"

gen time_s_survey =  (Started_end - Started_survey)/60000
label var time_s_survey "Duration of Survey (min)"

gen time_s_all = (Started_end - Started_intro)/60000
label var time_s_all "Duration of Chatbot (min)"

foreach var of varlist time_s_treat time_s_eval time_s_survey time_s_all {
	gen p50_`var'=.
	label var p50_`var' "Median `: variable label `var''"
	local l = 1 
		
	forval i=0/4 {
		replace t_tr="`: label l_treatment_status `i''" in `l'
		sum `var' if treatment_status==`i', d
		replace p50_`var'=`r(p50)' in `l'
		local l = `l' + 1
}

sum `var', d
replace p50_`var'=`r(p50)' in `l'

}

export excel t_tr p50_* using "${dir}/Results/Appendix G.xlsx", sheetreplace firstrow(varlabels) 

/*====================================================================
							Appendix H
====================================================================*/

violinplot ad_ds6, over(treatment_status) ylabel(0 "Control" -1 "Placebo" -2 `" "Comprehensive" "Active" "Inoculation" "'  -3 `" "Brief" "Active" "Inoculation" "' -4 `" "Passive" "Inoculation" "', labsize(small)) xtitle("Misinformation Discernment")
graph export "${dir}/Results/Appendix H1.png", replace

violinplot miss, over(treatment_status) ylabel(0 "Control" -1 "Placebo" -2 `" "Comprehensive" "Active" "Inoculation" "'  -3 `" "Brief" "Active" "Inoculation" "' -4 `" "Passive" "Inoculation" "', labsize(small)) xtitle("Misinformation Judgements of Misleading Headline")
graph export "${dir}/Results/Appendix H2.png", replace

violinplot non_miss, over(treatment_status) ylabel(0 "Control" -1 "Placebo" -2 `" "Comprehensive" "Active" "Inoculation" "'  -3 `" "Brief" "Active" "Inoculation" "' -4 `" "Passive" "Inoculation" "', labsize(small)) xtitle("Misinformation Judgements of Non-Misleading Headline")
graph export "${dir}/Results/Appendix H3.png", replace

violinplot ad_share, over(treatment_status) ylabel(0 "Control" -1 "Placebo" -2 `" "Comprehensive" "Active" "Inoculation" "'  -3 `" "Brief" "Active" "Inoculation" "' -4 `" "Passive" "Inoculation" "', labsize(small)) xtitle("Sharing Discernment")
graph export "${dir}/Results/Appendix H4.png", replace

violinplot share_q2, over(treatment_status) ylabel(0 "Control" -1 "Placebo" -2 `" "Comprehensive" "Active" "Inoculation" "'  -3 `" "Brief" "Active" "Inoculation" "' -4 `" "Passive" "Inoculation" "', labsize(small)) xtitle("Misleading Headline Sharing")
graph export "${dir}/Results/Appendix H5.png", replace

violinplot share_q1, over(treatment_status) ylabel(0 "Control" -1 "Placebo" -2 `" "Comprehensive" "Active" "Inoculation" "'  -3 `" "Brief" "Active" "Inoculation" "' -4 `" "Passive" "Inoculation" "', labsize(small))  xtitle("Non-Misleading Headline Sharing")
graph export "${dir}/Results/Appendix H6.png", replace


/*====================================================================
							Appendix I
====================================================================*/

preserve

keep if treatment_status==1 | treatment_status==4
clonevar d_check=i_d_check
replace d_check=p_d_check if p_d_check!=.

collapse (mean) m_ad_ds6=ad_ds6 (sd) sd_ad_ds6=ad_ds6 (count) n_ad_ds6=ad_ds6 (mean) m_ad_share=ad_share (sd) sd_ad_share=ad_share (count) n_ad_share=ad_share, by(d_check treatment_status)

generate hi_ad_ds6 = m_ad_ds6 + invttail(n_ad_share-1,0.025)*(sd_ad_ds6 / sqrt(n_ad_share))
generate lo_ad_ds6 = m_ad_ds6 - invttail(n_ad_share-1,0.025)*(sd_ad_ds6 / sqrt(n_ad_share))

generate hi_ad_share = m_ad_share + invttail(n_ad_share-1,0.025)*(sd_ad_share / sqrt(n_ad_share))
generate lo_ad_share = m_ad_share - invttail(n_ad_share-1,0.025)*(sd_ad_share / sqrt(n_ad_share))

gen t_check= d_check if treatment_status==1
replace t_check= d_check + 3 if treatment_status==4
sort t_check

graph twoway (bar m_ad_ds6 t_check if d_check==0) (bar m_ad_ds6 t_check if d_check==1) (rcap hi_ad_ds6 lo_ad_ds6 t_check), legend(row(1) order (1 "Failed Attention Checks" 2 "Succeeded all Attention Checks" )) legend(size(small)) xlabel(0.5 "Placebo" 3.5 "Infographics", noticks) ytitle("Misinformation Discernment") xtitle("")
graph export "${dir}/Results/Appendix I1.png", replace

graph twoway (bar m_ad_share t_check if d_check==0) (bar m_ad_share t_check if d_check==1) (rcap hi_ad_share lo_ad_share t_check), legend(row(1) order (1 "Failed Attention Checks" 2 "Succeeded all Attention Checks" )) legend(size(small)) xlabel(0.5 "Placebo" 3.5 "Infographics", noticks) ytitle("Sharing Discernment") xtitle("")
graph export "${dir}/Results/Appendix I2.png", replace

restore

/*====================================================================
							Appendix J
====================================================================*/

// Table J1

foreach var of varlist std_ad_ds6 std_miss std_non_miss std_ad_share std_share_q2 std_share_q1   std_r_confidence std_challenging std_r_recommend  {
	reg `var' ib1.treatment_status if education!=. & vaccination!=., r
	outreg2 using "${dir}/Results/Table J1.xls", append label dec(3)
	
	reg `var' ib1.treatment_status i.age i.education i.survey_gender i.vaccination if education!=., r
	outreg2 using "${dir}/Results/Table J1.xls", append label dec(3)
}


* Westfall-Young stepdown adjusted p-values
foreach i of numlist 0 2 3 4 {
wyoung std_ad_ds6 std_miss std_non_miss std_ad_share std_share_q2 std_share_q1   std_r_confidence std_challenging std_r_recommend, cmd(reg OUTCOMEVAR ib1.treatment_status if education!=., r) familyp(`i'.treatment_status) bootstraps(1000) seed(1984)
}

// Table J2


foreach var of varlist std_ad_ds5 {
	reg `var' ib1.treatment_status i.age i.education i.survey_gender i.vaccination if education!=., r
	outreg2 using "${dir}/Results/Table J2.xls", append label dec(3)
}

// Table J3

preserve

*Keep only complete cases
drop if missing(education)
drop if survey_gender == 3
drop if age == 6
drop if education == 5

** Add gender
mat gen2 = ( 49.2299, 50.7701)
mat colnames gen2 = 1 2
mat coleq gen2 = _tmp
mat rownames gen2 = survey_gender

** Add age distribution
clonevar ad_age=age
mat age2 = ( 27.9026, 19.0697, 18.3393,	16.0376, 18.6508)
mat colnames age2 = 1 2 3 4 5
mat coleq age2 = _tmp
mat rownames age2 = ad_age

** Add education
mat educ2 = ( 8.9274, 22.4938, 37.6483, 30.9305)
mat colnames educ2 = 1 2 3 4
mat coleq educ2 = _tmp
mat rownames educ2 = education

*Calculate sample estimates
gen byte _tmp = 1
egen sample_size = total(_tmp)


*Calcluate pop weight
gen pop = sample_size
gen pwgt = sample_size/pop

egen strata=concat(education survey_gender ad_age), punct(,)

svyset [pw=pwgt],strata(strata)

ipfraking [pw=pwgt], gen(weight) ctotal(gen2 age2 educ2) iterate(500)

svyset [pw=weight],strata(strata)


foreach var of varlist std_ad_ds6 std_miss std_non_miss std_ad_share std_share_q2 std_share_q1   std_r_confidence std_challenging std_r_recommend  {
	
	reg `var' ib1.treatment_status i.age i.education i.survey_gender i.vaccination [pw=weight] if education!=., r
	outreg2 using "${dir}/Results/Table J5.xls", append label dec(3)
}



* Westfall-Young stepdown adjusted p-values
foreach i of numlist 0 2 3 4 {
wyoung std_ad_ds6 std_miss std_non_miss std_ad_share std_share_q2 std_share_q1   std_r_confidence std_challenging std_r_recommend, cmd(reg OUTCOMEVAR ib1.treatment_status i.age i.education i.survey_gender i.vaccination [pw=weight] if education!=., r) familyp(`i'.treatment_status) bootstraps(1000) seed(1984)
}

restore

/*====================================================================
							Appendix K
====================================================================*/

foreach var of varlist std_ad_ds6  std_miss std_non_miss std_ad_share std_share_q2 std_share_q1 {
	reg `var' ib1.treatment_status##i.age ib1.treatment_status##i.education ib1.treatment_status##i.survey_gender ib1.treatment_status##i.vaccination if education!=., r
	outreg2 using "${dir}/Results/Appendix K.xls", append label dec(3)
}

/*====================================================================
								END
====================================================================*/
